@@ -34,11 +34,19 @@ import urlparse
 import xmlrpclib
 
 import simplejson
-from linaro_json.extensions import datetime_extension
+from json_schema_validator.extensions import datetime_extension
 
 from lava_tool.authtoken import AuthenticatingServerProxy, KeyringAuthBackend
-from lava_tool.commands import ExperimentalCommandMixIn
-from lava_tool.interface import Command
+from lava.tool.commands import ExperimentalCommandMixIn
+from lava.tool.command import Command, CommandGroup
+
+
+class dashboard(CommandGroup):
+    """
+    Commands for interacting with LAVA Dashboard
+    """
+
+    namespace = "lava.dashboard.commands"
 
 
 class InsufficientServerVersion(Exception):
